==> prestashop_1.5.0.15.zip: prestashop/modules/carriercompare/translations/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{carriercompare}prestashop>carriercompare_115484428c82f859100c07ae1170d9e0'] = 'Estimation des livraisons';
$_MODULE['<{carriercompare}prestashop>carriercompare_68e114c207a6820a8f14d0eceacf17d7'] = 'Module permettant de faire une estimation des coûts de livraison avant d\'entrer dans le processus de commande';
$_MODULE['<{carriercompare}prestashop>carriercompare_ed70a57a190d596171cf324c16a2277d'] = 'identifiant d\'état non valable';
$_MODULE['<{carriercompare}prestashop>carriercompare_ff22c3e7b4cd12813e2033774d987e96'] = 'Choissisez un état';
$_MODULE['<{carriercompare}prestashop>carriercompare_fb9e838d470b2c27c2c128d127165f9e'] = 'Choississez un pays';
$_MODULE['<{carriercompare}prestashop>carriercompare_b72dd62d03697b37417288c63e78c8c6'] = 'Veuillez utiliser un code postal valable en fonction du pays choisi';
$_MODULE['<{carriercompare}prestashop>carriercompare_3f63451bbacbb1c3303d99d0309fdfe9'] = 'Veuillez choisir un transporteur';
$_MODULE['<{carriercompare}prestashop>carriercompare_efaf5c3827ef576b05de32ad458f196c'] = 'Cet identifiant de transporteur n\'est pas disponible pour votre sélection';
$_MODULE['<{carriercompare}prestashop>carriercompare_a0593567d9366b570d33cd3ac81042df'] = 'Impossible de mettre à jour le panier';
$_MODULE['<{carriercompare}prestashop>carriercompare_e7a6ca4e744870d455a57b644f696457'] = 'Offert !';
$_MODULE['<{carriercompare}prestashop>carriercompare_fbc1bef527a3a092053a244fd8d87abf'] = 'Estimez vos frais de livraison & taxes';
$_MODULE['<{carriercompare}prestashop>carriercompare_59716c97497eb9694541f7c3d37b1a4d'] = 'Pays';
$_MODULE['<{carriercompare}prestashop>carriercompare_46a2a41cc6e552044816a2d04634545d'] = 'État';
$_MODULE['<{carriercompare}prestashop>carriercompare_e0ed8e71dbd22a1e91cb570b52443fd5'] = 'Code postal';
$_MODULE['<{carriercompare}prestashop>carriercompare_51e304bfd2872c9f53c99054b8fb8381'] = 'Nécessaires pour certains transporteurs';
$_MODULE['<{carriercompare}prestashop>carriercompare_914419aa32f04011357d3b604a86d7eb'] = 'Transporteur';
$_MODULE['<{carriercompare}prestashop>carriercompare_a82be0f551b8708bc08eb33cd9ded0cf'] = 'Information';
$_MODULE['<{carriercompare}prestashop>carriercompare_3601146c4e948c32b6424d2c0a7f0118'] = 'Prix';
$_MODULE['<{carriercompare}prestashop>carriercompare_f620c0ed0c89129c9dd8953406300061'] = 'Aucun  transporteur n\'est disponible pour cette sélection';
$_MODULE['<{carriercompare}prestashop>carriercompare_63a6a88c066880c5ac42394a22803ca6'] = 'Rafraîchir';
$_MODULE['<{carriercompare}prestashop>carriercompare_36126598ecb1141cd37a92f48e7727f1'] = 'Rafraîchissement de la page et mise à jour du panier...';
$_MODULE['<{carriercompare}prestashop>carriercompare_43b6864a312731efd637b6f15716656f'] = 'Vérification des états disponibles...';
$_MODULE['<{carriercompare}prestashop>carriercompare_c38be8e252777b47067cfe4de79b80a3'] = 'Récupération de l\'information...';
$_MODULE['<{carriercompare}prestashop>carriercompare_8a1ac57c0cc4eb3f6b2fe4c252518c37'] = 'Mettre à jour le panier';
$_MODULE['<{carriercompare}prestashop>carriercompare_653e78154f5596fc293bf9db65110bbd'] = 'Mettre à jour la liste des transporteurs';
$_MODULE['<{carriercompare}prestashop>configuration_aa4c031e8f3c596aaac3ba13f5f91c75'] = 'Une erreur est survenue lors de la validation du formulaire';
$_MODULE['<{carriercompare}prestashop>configuration_20015706a8cbd457cbb6ea3e7d5dc9b3'] = 'Configuration mise à jour';
$_MODULE['<{carriercompare}prestashop>configuration_6408d076fa6417e7bc8ddc3cdf9a0644'] = 'Configuration globale';
$_MODULE['<{carriercompare}prestashop>configuration_4c1f76824b0d7333652d5f64a3e07ef5'] = 'N\'importe quand';
$_MODULE['<{carriercompare}prestashop>configuration_d82928a663ff868502586a0c515e602b'] = 'Quand toutes les informations sont complètes';
$_MODULE['<{carriercompare}prestashop>configuration_7a23a5abbb503885bf1d6186033eca81'] = 'Défini la manière dont l\'information présentée à l\'utilisateur doit être rafraîchie';
$_MODULE['<{carriercompare}prestashop>configuration_a4d3b161ce1309df1c4e25df28694b7b'] = 'Valider';

==> prestashop_1.5.2.0.zip: prestashop/modules/carriercompare/translations/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{carriercompare}prestashop>carriercompare_115484428c82f859100c07ae1170d9e0'] = 'Estimation des livraisons';
$_MODULE['<{carriercompare}prestashop>carriercompare_68e114c207a6820a8f14d0eceacf17d7'] = 'Module permettant de faire une estimation des coûts de livraison avant d\'entrer dans le processus de commande';
$_MODULE['<{carriercompare}prestashop>carriercompare_ed70a57a190d596171cf324c16a2277d'] = 'identifiant d\'état non valable';
$_MODULE['<{carriercompare}prestashop>carriercompare_ff22c3e7b4cd12813e2033774d987e96'] = 'Choissisez un état';
$_MODULE['<{carriercompare}prestashop>carriercompare_fb9e838d470b2c27c2c128d127165f9e'] = 'Choississez un pays';
$_MODULE['<{carriercompare}prestashop>carriercompare_b72dd62d03697b37417288c63e78c8c6'] = 'Veuillez utiliser un code postal valable en fonction du pays choisi';
$_MODULE['<{carriercompare}prestashop>carriercompare_3f63451bbacbb1c3303d99d0309fdfe9'] = 'Veuillez choisir un transporteur';
$_MODULE['<{carriercompare}prestashop>carriercompare_efaf5c3827ef576b05de32ad458f196c'] = 'Cet identifiant de transporteur n\'est pas disponible pour votre sélection';
$_MODULE['<{carriercompare}prestashop>carriercompare_a0593567d9366b570d33cd3ac81042df'] = 'Impossible de mettre à jour le panier';
$_MODULE['<{carriercompare}prestashop>carriercompare_e7a6ca4e744870d455a57b644f696457'] = 'Offert !';
$_MODULE['<{carriercompare}prestashop>carriercompare_fbc1bef527a3a092053a244fd8d87abf'] = 'Estimez vos frais de livraison & taxes';
$_MODULE['<{carriercompare}prestashop>carriercompare_59716c97497eb9694541f7c3d37b1a4d'] = 'Pays';
$_MODULE['<{carriercompare}prestashop>carriercompare_46a2a41cc6e552044816a2d04634545d'] = 'État';
$_MODULE['<{carriercompare}prestashop>carriercompare_e0ed8e71dbd22a1e91cb570b52443fd5'] = 'Code postal';
$_MODULE['<{carriercompare}prestashop>carriercompare_51e304bfd2872c9f53c99054b8fb8381'] = 'Nécessaires pour certains transporteurs';
$_MODULE['<{carriercompare}prestashop>carriercompare_914419aa32f04011357d3b604a86d7eb'] = 'Transporteur';
$_MODULE['<{carriercompare}prestashop>carriercompare_a82be0f551b8708bc08eb33cd9ded0cf'] = 'Information';
$_MODULE['<{carriercompare}prestashop>carriercompare_3601146c4e948c32b6424d2c0a7f0118'] = 'Prix';
$_MODULE['<{carriercompare}prestashop>carriercompare_f620c0ed0c89129c9dd8953406300061'] = 'Aucun  transporteur n\'est disponible pour cette sélection';
$_MODULE['<{carriercompare}prestashop>carriercompare_63a6a88c066880c5ac42394a22803ca6'] = 'Rafraîchir';
$_MODULE['<{carriercompare}prestashop>carriercompare_36126598ecb1141cd37a92f48e7727f1'] = 'Rafraîchissement de la page et mise à jour du panier...';
$_MODULE['<{carriercompare}prestashop>carriercompare_43b6864a312731efd637b6f15716656f'] = 'Vérification des états disponibles...';
$_MODULE['<{carriercompare}prestashop>carriercompare_c38be8e252777b47067cfe4de79b80a3'] = 'Récupération de l\'information...';
$_MODULE['<{carriercompare}prestashop>carriercompare_8a1ac57c0cc4eb3f6b2fe4c252518c37'] = 'Mettre à jour le panier';
$_MODULE['<{carriercompare}prestashop>carriercompare_653e78154f5596fc293bf9db65110bbd'] = 'Mettre à jour la liste des transporteurs';
$_MODULE['<{carriercompare}prestashop>configuration_aa4c031e8f3c596aaac3ba13f5f91c75'] = 'Une erreur est survenue lors de la validation du formulaire';
$_MODULE['<{carriercompare}prestashop>configuration_20015706a8cbd457cbb6ea3e7d5dc9b3'] = 'Configuration mise à jour';
$_MODULE['<{carriercompare}prestashop>configuration_963744bc6b0cce93e202d860a4a2f84a'] = 'Ce module est disponible uniquement sur les processus de commande standard, car sur le One Page Checkout la liste des transporteurs est déjà disponible.';
$_MODULE['<{carriercompare}prestashop>configuration_6408d076fa6417e7bc8ddc3cdf9a0644'] = 'Configuration globale';
$_MODULE['<{carriercompare}prestashop>configuration_4c1f76824b0d7333652d5f64a3e07ef5'] = 'N\'importe quand';
$_MODULE['<{carriercompare}prestashop>configuration_d82928a663ff868502586a0c515e602b'] = 'Quand toutes les informations sont complètes';
$_MODULE['<{carriercompare}prestashop>configuration_7a23a5abbb503885bf1d6186033eca81'] = 'Défini la manière dont l\'information présentée à l\'utilisateur doit être rafraîchie';
$_MODULE['<{carriercompare}prestashop>configuration_a4d3b161ce1309df1c4e25df28694b7b'] = 'Valider';
